@@ -17,11 +17,7 @@
 class MarkdownBrowserExtension;
 class MarkdownView;
 class SearchToolBar;
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
 class KPluginMetaData;
-#else
-class KAboutData;
-#endif
 class QTextDocument;
 
 
@@ -38,11 +34,7 @@ public:
     /**
      * Default constructor, with arguments as expected by MarkdownPartFactory
      */
-#if KPARTS_VERSION >= QT_VERSION_CHECK(5, 77, 0)
     MarkdownPart(QWidget* parentWidget, QObject* parent, const KPluginMetaData& metaData, Modus modus);
-#else
-    MarkdownPart(QWidget* parentWidget, QObject* parent, const KAboutData& aboutData, Modus modus);
-#endif
     ~MarkdownPart() override;
 
 public:
